@@ -18,7 +18,7 @@ class NoWdPathsHypTree(ComplexityIndex):
             reduce_function: MeasureFunction):
 
         ComplexityIndex.__init__(self, lang=lang, category=IndexCategory.WORD,
-                                 abbr="WdPathHypernymTree", reduce_depth=reduce_depth,
+                                 abbr="PathsHypernymTree", reduce_depth=reduce_depth,
                                  reduce_function=reduce_function)
 
     def process(self, element: TextElement) -> float:
